@@ -11,6 +11,7 @@ from ._exceptions import (
     ProxyError,
     ReadError,
     ReadTimeout,
+    TimeoutException,
     WriteError,
     WriteTimeout,
 )
@@ -27,6 +28,7 @@ __all__ = [
     "SyncByteStream",
     "SyncConnectionPool",
     "SyncHTTPProxy",
+    "TimeoutException",
     "PoolTimeout",
     "ConnectTimeout",
     "ReadTimeout",
@@ -37,4 +39,4 @@ __all__ = [
     "WriteError",
     "CloseError",
 ]
-__version__ = "0.7.0"
+__version__ = "0.8.0"
